@@ -1,5 +1,6 @@
 /***********************************************************************
 Author(s): Pieter Kempeneers
+           Francesco Lovergine <autobot@lovergine.com>
 Copyright (C) 2000-2024 European Union (Joint Research Centre)
 
 This file is part of miallib.
@@ -19,20 +20,31 @@ along with miallib.  If not, see <https://www.gnu.org/licenses/>.
 ***********************************************************************/
 
 /*
-** Header file for myhull.cc
+** Header file for myhull.c
 */
 
 #ifndef _MYHULL_H
 #define _MYHULL_H
 
-#include <vector>
-
 /* for point with integer coordinates */
 typedef struct {
     int a;
     int b;
 } intpair_t;
 
-std::vector<intpair_t> chainHull_2D(std::vector<intpair_t>& points);
+/* Function to find the convex hull using Andrew's monotone chain algorithm 
+ * points: array of input points
+ * n: number of input points
+ * hull: pre-allocated array to store the resulting hull points (should be at least n+1 in size)
+ * returns: number of points in the hull
+ */
+int chainHull_2D(intpair_t *points, int n, intpair_t *hull);
 
-#endif /* _MYHULL_H */
\ No newline at end of file
+/* Compute convex hull of an image with labels
+ * ilbl: input labeled image
+ * graph: connectivity (4 or 8)
+ * returns: image with hull points marked
+ */
+IMAGE *chull(IMAGE *ilbl, int graph);
+
+#endif /* _MYHULL_H */
