@@ -1505,7 +1505,7 @@ int MAXROIVAL  =  65534;   /* pixels outside ROI should be at 255,
 int OUTROI     = 65535;
 
 
-extern ERROR_TYPE set_seq_shift();
+extern ERROR_TYPE set_seq_shift(long int , long int , long int , long int , long int *);
 
 void GreyAttributeClosingROI ( double lambdaVal,    /* threshold on attribute */
                             int width,        /* image width  */
